#!/bin/sh

/sbin/ldconfig > /dev/null 2> /dev/null
/usr/bin/shlibsign -i /lib/libsoftokn3.so >/dev/null 2>/dev/null
/usr/bin/shlibsign -i /lib/libfreebl3.so >/dev/null 2>/dev/null

( cd usr/lib ; rm -rf libssl3.so )
( cd usr/lib ; ln -sf ../../lib/libssl3.so libssl3.so )
( cd usr/lib ; rm -rf libfreebl3.chk )
( cd usr/lib ; ln -sf ../../lib/libfreebl3.chk libfreebl3.chk )
( cd usr/lib ; rm -rf libsoftokn3.so )
( cd usr/lib ; ln -sf ../../lib/libsoftokn3.so libsoftokn3.so )
( cd usr/lib ; rm -rf libnss3.so )
( cd usr/lib ; ln -sf ../../lib/libnss3.so libnss3.so )
( cd usr/lib ; rm -rf libnssckbi.so )
( cd usr/lib ; ln -sf ../../lib/libnssckbi.so libnssckbi.so )
( cd usr/lib ; rm -rf libnssdbm3.so )
( cd usr/lib ; ln -sf ../../lib/libnssdbm3.so libnssdbm3.so )
( cd usr/lib ; rm -rf libfreebl3.so )
( cd usr/lib ; ln -sf ../../lib/libfreebl3.so libfreebl3.so )
( cd usr/lib ; rm -rf libnssutil3.so )
( cd usr/lib ; ln -sf ../../lib/libnssutil3.so libnssutil3.so )
( cd usr/lib ; rm -rf libsoftokn3.chk )
( cd usr/lib ; ln -sf ../../lib/libsoftokn3.chk libsoftokn3.chk )
( cd usr/lib ; rm -rf libsmime3.so )
( cd usr/lib ; ln -sf ../../lib/libsmime3.so libsmime3.so )
